# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

from squish import waitForObject
import names
import test


def toolbar(backButton, themeButton, backButtonEnabled, themeButtonEnabled, backButtonOpacity, themeButtonOpacity):
    test.log(f"Test that back button enabled property equals to {backButtonEnabled}")
    test.compare(backButton.enabled, backButtonEnabled)
    test.log(f"Test that theme button enabled property equals to {themeButtonEnabled}")
    test.compare(themeButton.enabled, themeButtonEnabled)
    test.log(f"Test that back button opacity is {backButtonOpacity}, 0 meaning completely transparent and 1 meaning not transparent")
    test.compare(backButton.opacity, backButtonOpacity)
    test.log(f"Test that theme button opacity is {themeButtonOpacity}")
    test.compare(themeButton.opacity, themeButtonOpacity)

def stackview(stackView, depth, page):
    test.log(f"Test that stack view depth is {depth} after moving to {page}")
    test.compare(stackView.depth, depth)

def settings(settingsPage):
    test.log(f"Test that settings page is visible after selecting {coffee}")
    test.compare(settingsPage.visible, True)

def testSliderValue(slider, sliderName, value):
    test.log(f"Test that {sliderName} value matches {value}")
    test.compare(slider.value, value)

def testCoffeeDefaultValues(coffeeAmount, milkAmount, foamAmount, sugarAmount):
    coffeePage = waitForObject(names.coffeeSettingsPage)
    test.log(f"Test that Pages coffeeAmount property value updates to {coffeeAmount}")
    test.compare(coffeePage.coffeeAmount, coffeeAmount)
    test.log(f"Test that Pages milkAmount property value updates to {milkAmount}")
    test.compare(coffeePage.milkAmount, milkAmount)
    test.log(f"Test that Pages foamAmount property value updates to {foamAmount}")
    test.compare(coffeePage.foamAmount, foamAmount)
    test.log(f"Test that Pages sugarAmount property value updates to {sugarAmount}")
    test.compare(coffeePage.sugarAmount, sugarAmount)


def testScreenBoundaries(applicationWindow, grid, toolbar, **kwargs):
    coffeeText = kwargs.get('coffeeText')
    if coffeeText is None:
            test.log("Test that application window height is greater than or equal to all the object heights combined inside it")
            test.verify(applicationWindow.height >= grid.height + toolbar.height)
    else:
        test.log("Test that application window height is greater than or equal to all the object heights combined inside it")
        test.verify(applicationWindow.height >= grid.height + coffeeText.height + toolbar.height)
        test.log(f"{applicationWindow.height} and {grid.height + coffeeText.height + toolbar.height}")
    test.log("Test that application window width is greater than or equal to grid width")
    test.verify(applicationWindow.width >= grid.width)

def testPageStateOrientation(page):
    screenOrientationValue = waitForObject(names.coffeeQQuickApplicationWindow).screen.orientation
    pageOrientationState = page.state
    orientationTestPass = False
    logValues = f"(State: '{pageOrientationState}', Value: '{screenOrientationValue}')"
    logDetails = "State portrait should have value 1 and landscape 2 or 8."
    test.log("Check that page state matches with Android screen orientation value")
    if pageOrientationState == 'landscape' and screenOrientationValue in (2, 8):
        orientationTestPass = True
    elif pageOrientationState == 'portrait' and screenOrientationValue == 1:
        orientationTestPass = True
    if orientationTestPass:
        test.passes(f"Page state matches with Android screen orientation value. {logValues}", logDetails)
    else:
        test.fail(f"Page state and Android screen orientation value mismatch. {logValues}", logDetails)



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared
from dataclasses import dataclass


@dataclass
class Coffee():
    name: str
    coffeeAmount: int
    milkAmount: int
    foamAmount: int
    sugarAmount: int
    button: object

def testCoffees():
    cappuccino = Coffee("cappuccino", 60, 60 ,60, 0, waitForObjectExists(names.cappuccinoButton))
    latte = Coffee("latte", 40, 20, 60, 0, waitForObjectExists(names.latteButton))
    espresso = Coffee("espresso", 80, 0, 0, 0, waitForObjectExists(names.espressoButton))
    macchiato = Coffee("macchiato", 100, 5, 10, 0, waitForObjectExists(names.macchiatoButton))
    coffeeList = [cappuccino, latte, espresso, macchiato]

    for coffee in coffeeList:
        test.log(f"Set shared.py coffee variable to {coffee.name}")
        shared.coffee = coffee.name
        test.log(f"Tap {coffee.name} card")
        tapObject(coffee.button)
        snooze(1)
        shared.settings(waitForObjectExists(names.coffeeSettingsPage))
        shared.testCoffeeDefaultValues(coffee.coffeeAmount, coffee.milkAmount, coffee.foamAmount, coffee.sugarAmount)
        shared.testSliderValue(waitForObject(names.sliderCoffee), "coffee slider", coffee.coffeeAmount)
        shared.testSliderValue(waitForObject(names.sliderMilk), "milk slider", coffee.milkAmount)
        shared.testSliderValue(waitForObject(names.sliderFoam), "foam slider", coffee.foamAmount)
        test.log("Tap back button to move back to coffee selection page")
        tapObject(waitForObject(names.toolBarBackButton))
        snooze(1)

def main():
    attachToApplication("coffeemachine")
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), False, True, 0, 1)
    shared.stackview(waitForObjectExists(names.applicationStackView), 2, "coffee selection page")
    test.log("Test that choosing coffee page state is same as screen orientation")
    shared.testPageStateOrientation(waitForObjectExists(names.coffeeHomePage))
    test.log("Test that cappuccino coffee card is visible")
    test.compare(waitForObjectExists(names.cappuccinoCard).visible, True)
    test.log("Test that button inside cappuccino coffee card is enabled")
    test.compare(waitForObjectExists(names.cappuccinoButton).enabled, True)
    test.log("Test that latte coffee card is visible")
    test.compare(waitForObjectExists(names.latteCard).visible, True)
    test.log("Test that button inside latte coffee card is enabled")
    test.compare(waitForObjectExists(names.latteButton).enabled, True)
    test.log("Test that espresso coffee card is visible")
    test.compare(waitForObjectExists(names.espressoCard).visible, True)
    test.log("Test that button inside espresso coffee card is enabled")
    test.compare(waitForObjectExists(names.espressoButton).enabled, True)
    test.log("Test that macchiato coffee card is visible")
    test.compare(waitForObjectExists(names.macchiatoCard).visible, True)
    test.log("Test that button inside macchiato coffee card is enabled")
    test.compare(waitForObjectExists(names.macchiatoButton).enabled, True)
    test.log("Test that there are 4 cappuccinos left")
    test.compare(waitForObjectExists(names.applicationFlow).cappuccinos, 4)
    test.log("Test that there are 5 lattes left")
    test.compare(waitForObjectExists(names.applicationFlow).lattes, 5)
    test.log("Test that there are 6 espressos left")
    test.compare(waitForObjectExists(names.applicationFlow).espressos, 6)
    test.log("Test that there are 4 macchiatos left")
    test.compare(waitForObjectExists(names.applicationFlow).macchiatos, 4)
    testCoffees()
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.choosingCardsGridLayout),
                                waitForObject(names.coffeeToolBar), coffeeText = waitForObject(names.coffeeHeaderText))
    test.log("Tap macchiato coffee card to move to Settings page testing")
    tapObject(waitForObject(names.macchiatoButton))



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared


def main():
    attachToApplication("coffeemachine")
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), False, True, 0, 1)
    shared.stackview(waitForObjectExists(names.applicationStackView), 5, "progress page")
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.progressGridLayout),
                                waitForObject(names.coffeeToolBar), coffeeText = waitForObject(names.coffeeHeaderText))
    test.log("Test that progress page has active focus on")
    test.compare(waitForObjectExists(names.coffeeProgressPage).activeFocus, True)
    progressBarWidth = waitForObject(names.progressBar).width
    test.log("Wait 1 sec so that progress bar length can be saved at 2 different points in time, which then should have different value")
    snooze(1)
    progressBarWidth2 = waitForObject(names.progressBar).width
    test.log("Verify that progress bar has made progress")
    test.verify(progressBarWidth < progressBarWidth2)



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names


def main():
    attachToApplication("calqlatr")

    # Digit buttons
    button0 = waitForObjectExists(names.digitButton0)
    button1 = waitForObjectExists(names.digitButton1)
    button2 = waitForObjectExists(names.digitButton2)
    button3 = waitForObjectExists(names.digitButton3)
    button4 = waitForObjectExists(names.digitButton4)
    button5 = waitForObjectExists(names.digitButton5)
    button6 = waitForObjectExists(names.digitButton6)
    button7 = waitForObjectExists(names.digitButton7)
    button8 = waitForObjectExists(names.digitButton8)
    button9 = waitForObjectExists(names.digitButton9)
    decimal = waitForObjectExists(names.decimal)

    # Main operations
    backspace = waitForObjectExists(names.backspaceButton)
    allClear = waitForObjectExists(names.allClearButton)
    plusMinus = waitForObjectExists(names.plusMinusButton)
    equals = waitForObjectExists(names.equalsButton)
    division = waitForObjectExists(names.divisionButton)
    multiplication = waitForObjectExists(names.multiplicationButton)
    plus = waitForObjectExists(names.plusButton)
    minus = waitForObjectExists(names.minusButton)

    test.log("Test that Zero button is visible")
    test.compare(button0.visible, True)
    test.log("Test that Zero button has text '0'")
    test.compare(button0.text, "0")
    test.log("Test that One button is visible")
    test.compare(button1.visible, True)
    test.log("Test that One button has text '1'")
    test.compare(button1.text, "1")
    test.log("Test that Two button is visible")
    test.compare(button2.visible, True)
    test.log("Test that Two button has text '2'")
    test.compare(button2.text, "2")
    test.log("Test that Three button is visible")
    test.compare(button3.visible, True)
    test.log("Test that Three button has text '3'")
    test.compare(button3.text, "3")
    test.log("Test that Four button is visible")
    test.compare(button4.visible, True)
    test.log("Test that Four button has text '4'")
    test.compare(button4.text, "4")
    test.log("Test that Five button is visible")
    test.compare(button5.visible, True)
    test.log("Test that Five button has text '5'")
    test.compare(button5.text, "5")
    test.log("Test that Six button is visible")
    test.compare(button6.visible, True)
    test.log("Test that Six button has text '6'")
    test.compare(button6.text, "6")
    test.log("Test that Seven button is visible")
    test.compare(button7.visible, True)
    test.log("Test that Seven button has text '7'")
    test.compare(button7.text, "7")
    test.log("Test that Eight button is visible")
    test.compare(button8.visible, True)
    test.log("Test that Eight button has text '8'")
    test.compare(button8.text, "8")
    test.log("Test that Nine button is visible")
    test.compare(button9.visible, True)
    test.log("Test that Nine button has text '9'")
    test.compare(button9.text, "9")
    test.log("Test that Decimal button is visible")
    test.compare(decimal.visible, True)
    test.log("Test that Decimal button has text '.'")
    test.compare(decimal.text, ".")

    test.log("Test that Backspace button is visible")
    test.compare(backspace.visible, True)
    test.log("Test that All Clear button is visible")
    test.compare(allClear.visible, True)
    test.log("Test that All Clear button has text 'AC'")
    test.compare(allClear.text, "AC")
    test.log("Test that PlusMinus button is visible")
    test.compare(plusMinus.visible, True)
    test.log("Test that PlusMinus button has text '±'")
    test.compare(plusMinus.text, "±")
    test.log("Test that Equals button is visible")
    test.compare(equals.visible, True)
    test.log("Test that Equals button has text '='")
    test.compare(equals.text, "=")
    test.log("Test that Division button is visible")
    test.compare(division.visible, True)
    test.log("Test that Division button has text '÷'")
    test.compare(division.text, "÷")
    test.log("Test that Multiplication button is visible")
    test.compare(multiplication.visible, True)
    test.log("Test that Multiplication button has text '×'")
    test.compare(multiplication.text, "×")
    test.log("Test that Plus button is visible")
    test.compare(plus.visible, True)
    test.log("Test that Plus button has text '+'")
    test.compare(plus.text, "+")
    test.log("Test that Minus button is visible")
    test.compare(minus.visible, True)
    test.log("Test that Minus button has text '−'")
    test.compare(minus.text, "−")

    if waitForObjectExists(names.landscapeMode).visible:
        test.log("Landscape mode extra tests")

        # Scientific Digit buttons
        euler = waitForObjectExists(names.digitButtonEuler)
        pi = waitForObjectExists(names.digitButtonPi)

        # Scientific operations
        squaring = waitForObjectExists(names.squaringButton)
        denominator = waitForObjectExists(names.denominatorButton)
        squareroot = waitForObjectExists(names.squareRootButton)
        cubed = waitForObjectExists(names.cubedButton)
        sin = waitForObjectExists(names.sinButton)
        absvalue = waitForObjectExists(names.absValueButton)
        logarithm = waitForObjectExists(names.logarithmButton)
        cos = waitForObjectExists(names.cosButton)
        naturalogarithm = waitForObjectExists(names.naturalLogarithmButton)
        tan = waitForObjectExists(names.tanButton)

        test.log("Test that Euler e button is visible")
        test.compare(euler.visible, True)
        test.log("Test that Euler e button has text 'e'")
        test.compare(euler.text, "e")
        test.log("Test that PI button is visible")
        test.compare(pi.visible, True)
        test.log("Test that PI button has text 'π'")
        test.compare(pi.text, "π")

        test.log("Test that Squared button is visible")
        test.compare(squaring.visible, True)
        test.log("Test that Squared button has text 'x²'")
        test.compare(squaring.text, "x²")
        test.log("Test that Denominator button is visible")
        test.compare(denominator.visible, True)
        test.log("Test that Denominator Root button has text '⅟x'")
        test.compare(denominator.text, "⅟x")
        test.log("Test that Square Root button is visible")
        test.compare(squareroot.visible, True)
        test.log("Test that Square Root button has text '√'")
        test.compare(squareroot.text, "√")
        test.log("Test that Cubed button is visible")
        test.compare(cubed.visible, True)
        test.log("Test that Cubed button has text 'x³'")
        test.compare(cubed.text, "x³")
        test.log("Test that Sine button is visible")
        test.compare(sin.visible, True)
        test.log("Test that Sine button has text 'sin'")
        test.compare(sin.text, "sin")
        test.log("Test that Absolute Value button is visible")
        test.compare(absvalue.visible, True)
        test.log("Test that Absolute Value button has text '|x|'")
        test.compare(absvalue.text, "|x|")
        test.log("Test that Logarithm button is visible")
        test.compare(logarithm.visible, True)
        test.log("Test that Logarithm button has text 'log'")
        test.compare(logarithm.text, "log")
        test.log("Test that Cosine button is visible")
        test.compare(cos.visible, True)
        test.log("Test that Cosine button has text 'cos'")
        test.compare(cos.text, "cos")
        test.log("Test that Natural Logarithm button is visible")
        test.compare(naturalogarithm.visible, True)
        test.log("Test that Natural Logarithm button has text 'ln'")
        test.compare(naturalogarithm.text, "ln")
        test.log("Test that Tangent button is visible")
        test.compare(tan.visible, True)
        test.log("Test that Tangent button has text 'tan'")
        test.compare(tan.text, "tan")



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared


def testCancelButton():
    test.log("Tap cancel button to move back to coffee selection page")
    tapObject(waitForObject(names.insertCancelButton))
    test.log("Test that stack view depth decreases to 2")
    test.compare(waitForObjectExists(names.applicationStackView).depth, 2)
    test.log("Test that coffee selection page has the active focus on")
    test.compare(waitForObjectExists(names.coffeeChoosingPage).activeFocus, True)
    test.log("Tap macchiato coffee card button in coffee selection page")
    tapObject(waitForObject(names.macchiatoButton))
    test.log("Tap confirm button in Settings page")
    tapObject(waitForObject(names.settingsConfirmButton))

def main():
    attachToApplication("coffeemachine")
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), True, True, 1, 1)
    shared.stackview(waitForObjectExists(names.applicationStackView), 4, "insert page")
    test.log("Test that Insert page state is same as screen orientation")
    shared.testPageStateOrientation(waitForObjectExists(names.coffeeHomePage))
    test.log("Test that cup image is visible")
    test.compare(waitForObjectExists(names.insertCupImageCollection).visible, True)
    test.log("Test that dialog is visible")
    test.compare(waitForObjectExists(names.insertDialog).visible, True)
    test.log("Test that text inside dialog is visible")
    test.compare(waitForObjectExists(names.insertDialogText).text, "Please insert your cup.")
    test.log("Test that continue button is visible")
    test.compare(waitForObjectExists(names.insertContinueButton).visible, True)
    test.log("Test that cancel button is visible")
    test.compare(waitForObjectExists(names.insertCancelButton).visible, True)
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.insertGridLayout),
                                waitForObject(names.coffeeToolBar), coffeeText = waitForObject(names.coffeeHeaderText))
    testCancelButton()
    test.log("Tap continue button to move to insert progress page")
    tapObject(waitForObject(names.insertContinueButton))



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared
from dataclasses import dataclass


@dataclass
class Slider:
    sliderObject: object
    sliderHandleObject: dict
    name: str
    value: int = 0
    def setSliderValue(self, value):
        test.log(f"Set {self.name} to {value}")
        waitForObject(self.sliderObject).value = value
        self.value = value

    def dragSlider(self, dragCount):
        slider = waitForObject(self.sliderObject)
        sliderHandle = waitForObject(self.sliderHandleObject)
        dragDistance = int(slider.width/dragCount)
        test.log(f"Drag {self.name} forwards")
        touchAndDrag(sliderHandle, 0, sliderHandle.height/2, dragDistance, sliderHandle.height/2)
        self.value = slider.value

def testSliders():
    coffeeSlider = Slider(waitForObject(names.sliderCoffee), names.sliderCoffeeHandle, "coffee slider")
    milkSlider = Slider(waitForObject(names.sliderMilk), names.sliderMilkHandle, "milk slider")
    foamSlider = Slider(waitForObject(names.sliderFoam), names.sliderFoamHandle, "foam slider")
    sugarSlider = Slider(waitForObject(names.sliderSugar), names.sliderSugarHandle, "sugar slider")
    sliders = [coffeeSlider, milkSlider, foamSlider, sugarSlider]
    for slider in sliders:
        if slider.name == "sugar slider":
            for _ in range (2):
                slider.dragSlider(2)
                shared.testSliderValue(slider.sliderObject, slider.name, slider.value)
                test.log("Test that sugar image opacity reflects the current sugar amount, opacity should be exactly the same as sugar slider value")
                test.compare(waitForObject(names.sugarImage).opacity, slider.value)
        else:
            slider.setSliderValue(0)
            for _ in range(3):
                coffeeImageHeight = waitForObject(names.coffeeImage).height
                milkImageHeight = waitForObject(names.milkImage).height
                foamImageHeight = waitForObject(names.foamImage).height
                slider.dragSlider(3)
                shared.testSliderValue(slider.sliderObject, slider.name, slider.value)
                if slider.name == "coffee slider":
                    test.log("Verify that coffee image height has increased since the coffee slider value was increased")
                    test.verify(waitForObject(names.coffeeImage).height > coffeeImageHeight)
                elif slider.name == "milk slider":
                    test.log("Verify that milk image height has increased since the milk slider value was increased")
                    test.verify(waitForObject(names.milkImage).height > milkImageHeight)
                elif slider.name == "foam slider":
                    test.log("Verify that foam image height has increased since the foam slider value was increased")
                    test.verify(waitForObject(names.foamImage).height > foamImageHeight)

def main():
    attachToApplication("coffeemachine")
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), True, True, 1, 1)
    shared.stackview(waitForObjectExists(names.applicationStackView), 3, "settings page")
    test.log("Test that Settings page state is same as screen orientation")
    shared.testPageStateOrientation(waitForObjectExists(names.coffeeHomePage))
    test.log("Test that ApplicationFlow coffeName text object text is 'Macchiato'")
    test.compare(waitForObjectExists(names.coffeeHeaderText).text, "Macchiato")
    testSliders()
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.settingsGridLayout),
                                waitForObject(names.coffeeToolBar), coffeeText = waitForObject(names.coffeeHeaderText))
    test.log("Tap start button to move to insert page")
    tapObject(waitForObject(names.settingsConfirmButton))



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names


def operator_button_not_available(button_list):
    for button in button_list:
        test.log(f"Check that {button.text} button has been dimmed (disabled before number press)")
        test.compare(button.dimmed, True)

def main():
    attachToApplication("calqlatr")

    button_list = (waitForObjectExists(names.backspaceButton),
                   waitForObjectExists(names.allClearButton),
                   waitForObjectExists(names.plusMinusButton),
                   waitForObjectExists(names.equalsButton),
                   waitForObjectExists(names.divisionButton),
                   waitForObjectExists(names.multiplicationButton),
                   waitForObjectExists(names.plusButton),
                   waitForObjectExists(names.minusButton),
                   waitForObjectExists(names.decimal))

    if waitForObjectExists(names.landscapeMode).visible:
        test.log("Landscape mode extra tests")
        scientific_button_list = (waitForObjectExists(names.squaringButton),
                       waitForObjectExists(names.denominatorButton),
                       waitForObjectExists(names.squareRootButton),
                       waitForObjectExists(names.cubedButton),
                       waitForObjectExists(names.sinButton),
                       waitForObjectExists(names.absValueButton),
                       waitForObjectExists(names.logarithmButton),
                       waitForObjectExists(names.cosButton),
                       waitForObjectExists(names.naturalLogarithmButton),
                       waitForObjectExists(names.tanButton))
        button_list = button_list + scientific_button_list

    operator_button_not_available(button_list)



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared


def main():
    attachToApplication("coffeemachine")
    test.log("Wait for ready page grid object to synchronize test script to application")
    waitForObject(names.coffeeReadyPage)
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), False, True, 0, 1)
    shared.stackview(waitForObjectExists(names.applicationStackView), 6, "ready page")
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.readyGridLayout),
                                waitForObject(names.coffeeToolBar), coffeeText = waitForObject(names.coffeeHeaderText))
    test.log("Test that ready page has active focus on")
    test.compare(waitForObjectExists(names.coffeeReadyPage).activeFocus, True)
    test.log("Test that coffee cup coffeeAmount property value equals 100")
    test.compare(waitForObjectExists(names.readyCupImageCollection).coffeeAmount, 100)
    test.log("Test that coffee cup milkAmount property value equals 5")
    test.compare(waitForObjectExists(names.readyCupImageCollection).milkAmount, 5)
    test.log("Test that coffee cup foamAmount property value equals 10")
    test.compare(waitForObjectExists(names.readyCupImageCollection).foamAmount, 10)
    test.log("Test that coffee cup sugarAmount property value equals 0.0")
    test.compare(waitForObjectExists(names.readyCupImageCollection).sugarAmount, 0.0)



# Copyright (C) 2025 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause

import names
import shared


def main():
    attachToApplication("coffeemachine")
    shared.toolbar(waitForObjectExists(names.toolBarBackButton), waitForObjectExists(names.toolBarThemeButton), False, False, 0, 0)
    shared.stackview(waitForObjectExists(names.applicationStackView), 1, "home page")
    test.log("Test that home page state is the same as screen orientation")
    shared.testPageStateOrientation(waitForObjectExists(names.coffeeHomePage))
    shared.testScreenBoundaries(waitForObject(names.applicationContentItem), waitForObject(names.homeGridLayout), waitForObject(names.coffeeToolBar))
    test.log("Tap 'Get Started' button and move to coffee selection page")
    tapObject(waitForObject(names.homeGetStartedButton))
